@@ -9,8 +9,8 @@
 """
 
 __title__ = 'd2lvalence'
-__version__ = '0.1.15'
-__build__ = 0x00010D
+__version__ = '1.0.0'
+__build__ = 0x010000
 __author__ = 'Desire2Learn Extensibility'
-__license__ = 'Apache v2'
+__license__ = 'Apache 2.0'
 __copyright__ = 'Copyright 2013 Desire2Learn Incorporated.'
